Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(107)

Unified Diff: lib/isolate/frog/messages.dart

Issue 9662024: Refactor, rename, and generally rationalize code in the Frog isolates library, (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/isolate/frog/isolateimpl.dart ('k') | lib/isolate/frog/ports.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/isolate/frog/messages.dart
===================================================================
--- lib/isolate/frog/messages.dart (revision 5844)
+++ lib/isolate/frog/messages.dart (working copy)
@@ -188,7 +188,7 @@
}
visitNativeJsSendPort(_NativeJsSendPort port) {
- return ['sendport', _globalState.currentWorkerId,
+ return ['sendport', _globalState.currentManagerId,
port._isolateId, port._receivePort._id];
}
@@ -282,18 +282,18 @@
}
SendPort _deserializeSendPort(List x) {
- int workerId = x[1];
+ int managerId = x[1];
int isolateId = x[2];
int receivePortId = x[3];
// If two isolates are in the same worker, we use NativeJsSendPorts to
// deliver messages directly without using postMessage.
- if (workerId == _globalState.currentWorkerId) {
+ if (managerId == _globalState.currentManagerId) {
var isolate = _globalState.isolates[isolateId];
if (isolate == null) return null; // Isolate has been closed.
var receivePort = isolate.lookup(receivePortId);
return new _NativeJsSendPort(receivePort, isolateId);
} else {
- return new _WorkerSendPort(workerId, isolateId, receivePortId);
+ return new _WorkerSendPort(managerId, isolateId, receivePortId);
}
}
}
@@ -282,18 +282,18 @@
int isolateId = x[2];
int receivePortId = x[3];
- // If two isolates are in the same worker, we use NativeJsSendPorts to
+ // If two isolates are in the same manager, we use NativeJsSendPorts to
// deliver messages directly without using postMessage.
« no previous file with comments | « lib/isolate/frog/isolateimpl.dart ('k') | lib/isolate/frog/ports.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698